Decrypter

Struct Decrypter 

pub struct Decrypter<In>
where In: Read,
{ /* private fields */ }
Available on crate feature stream only.
A streaming AES-GCM-SIV 256-bits decrypter.

Implements the Read trait to provide streaming, while internally keeping a buffer of the chunk to decrypt as a single message.

Note: The size of the chunk used must match the chunk size used by the Encrypter. The decryption will fail if there is a mismatch.

Examples

use std::io::BufRead;

let key = get_key();
let decrypter = crypter::stream::Decrypter::new(&key, stdin())
   .expect("Failed to read from stdin");
let reader = std::io::BufReader::new(decrypter);

for line in reader.lines() {
    let line = line.expect("Failed to read from stdin");
    println!("{line}");
}

Implementations

Source

impl<In> Decrypter<In>
where In: Read,

pub fn new<'k, Key>(key: Key, input: In) -> Result<Self>
where Key: Into<&'k Key<Aes256GcmSiv>>,

Creates a new Decrypter using the reader input and a default size DEFAULT_CHUNK decrypted with the cryptographic key key.

Errors

When initializing, the Decrypter will read the first few bytes of input. If any error happens at that stage, this function will fail.

pub fn new_with_password<Password>( password: Password, input: In, ) -> Result<Self>
where Password: AsRef<[u8]>,

Available on crate feature argon only.

Creates a new Decrypter using the reader input and a default size DEFAULT_CHUNK decrypted with the cryptographic key derived from password using Argon2.

Errors
  • If the key derivation fails, an InvalidData is returned;
  • When initializing, the Decrypter will read the first few bytes of input. If any error happens at that stage, this function will fail.
pub fn with_chunk<'k, Key>(key: Key, input: In, chunk: usize) -> Result<Self>
where Key: Into<&'k Key<Aes256GcmSiv>>,

Creates a new Decrypter using the reader input and a chunk size chunk decrypted with the cryptographic key key.

Errors
  • If the value of chunk is less than 32, an InvalidInput is returned.
  • When initializing, the Decrypter will read the first few bytes of input. If any error happens at that stage, this function will fail.
pub fn with_chunk_with_password<Password>( password: Password, input: In, chunk: usize, ) -> Result<Self>
where Password: AsRef<[u8]>,

Available on crate feature argon only.

Creates a new Decrypter using the reader input and a chunk size chunk decrypted with the cryptographic key derived from password using Argon2.

Errors
  • If the value of chunk is less than 32, an InvalidInput is returned.
  • If the key derivation fails, an InvalidData is returned;
  • When initializing, the Decrypter will read the first few bytes of input. If any error happens at that stage, this function will fail.